otcextensions.sdk.apig.v2.certificate
=====================================

.. automodule:: otcextensions.sdk.apig.v2.certificate

The Certificate Class
---------------------

The ``Certificate`` class inherits from
:class:`~otcextensions.sdk.sdk_resource.Resource`.

.. autoclass:: otcextensions.sdk.apig.v2.certificate.Certificate
   :members:
